@@ -316,9 +316,9 @@ class Connection():
 
     def __format_object_insert_query__(self, obj):
         table =  self._inflector.tableize(obj.__class__.__name__)
-        keys = ', '.join([key for key, value in obj.__metadata__['data'].items() if value])
-        values = ', '.join([f'%({key})s' for key, value in obj.__metadata__['data'].items() if value])
-        on_keys = ', '.join([f"{key}=%({key})s" for key, value in obj.__metadata__['data'].items() if value])
+        keys = ', '.join([key for key, value in obj.__metadata__['data'].items() if value is not None])
+        values = ', '.join([f'%({key})s' for key, value in obj.__metadata__['data'].items() if value is not None])
+        on_keys = ', '.join([f"{key}=%({key})s" for key, value in obj.__metadata__['data'].items() if value is not None])
         return f"INSERT INTO {table} ({keys}) VALUES ({values}) ON DUPLICATE KEY UPDATE {on_keys}"
 
     def select(self, *fields):
@@ -452,7 +452,7 @@ class Connection():
         Debug("Saving Object")
         def do_object(_obj):
             _add_query = self.__format_object_insert_query__(_obj)
-            _last_row_id = self._conn.save(_add_query, {key:value for key, value in _obj.__metadata__['data'].items() if value})
+            _last_row_id = self._conn.save(_add_query, {key:value for key, value in _obj.__metadata__['data'].items() if value is not None})
             if _last_row_id:
                 _pk_key = obj.__metadata__['pk'][0]
                 _obj.__setattr__(_pk_key, _last_row_id)
